pggls(formula, data, subset, na.action, effect = c("individual","time"), model = c("within","random","pooling","fd"),
index = NULL, ...)
## S3 method for class 'pggls':
summary(object, ...)
## S3 method for class 'summary.pggls':
print(x,digits = max(3, getOption("digits") -
2), width = getOption("width"),...)pggls,data.frame,lm,lm,"individual" or "time","within", "random", "pooling"
or "fd",plm.data,c("pggls","panelmodel") containing:effect="time") covariance of errors,pggls is a function for the estimation of linear panel models by general feasible generalized least squares, either with or without fixed effects. General FGLS is based on a two-step estimation process: first a model is estimated by OLS (random) or fixed effects (within), then its residuals are used to estimate an error covariance matrix for use in a feasible-GLS analysis. This framework allows the error covariance structure inside every group (if effect="individual", else symmetric) of observations to be
fully unrestricted and is therefore robust against any type of
intragroup heteroskedasticity and serial correlation. Conversely, this
structure is assumed identical across groups and thus general FGLS
estimation is inefficient under groupwise heteroskedasticity. Note also
that this method requires estimation of $T(T+1)/2$ variance
parameters, thus efficiency requires N > > T (if
effect="individual", else the opposite).
The model="random" and model="pooling" arguments both
produce an unrestricted FGLS model as in Wooldridge, Ch.10. If
model="within" (the default) then a FEGLS (fixed effects GLS, see
ibid.) is estimated; if model="fd" a FDGLS (first-difference GLS).data("Produc", package = "plm")
zz <- pggls(log(gsp) ~ log(pcap) + log(pc) + log(emp) + unemp, data = Produc, model = "pooling")
summary(zz)Run the code above in your browser using DataLab